@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    action.c for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -29,6 +30,7 @@
 #include "grab.h"
 #include "keyboard.h"
 #include "event.h"
+#include "dock.h"
 #include "config.h"
 #include "mainloop.h"
 
@@ -471,6 +473,11 @@ ActionString actionstrings[] =
         action_iconify,
         setup_client_action
     },
+    {
+        "focustobottom",
+        action_focus_order_to_bottom,
+        setup_client_action
+    },
     {
         "raiselower",
         action_raiselower,
@@ -536,6 +543,11 @@ ActionString actionstrings[] =
         action_move_relative_vert,
         setup_client_action
     },
+    {
+        "movetocenter",
+        action_move_to_center,
+        setup_client_action
+    },
     {
         "resizerelativehorz",
         action_resize_relative_horz,
@@ -546,6 +558,16 @@ ActionString actionstrings[] =
         action_resize_relative_vert,
         setup_client_action
     },
+    {
+        "moverelative",
+        action_move_relative,
+        setup_client_action
+    },
+    {
+        "resizerelative",
+        action_resize_relative,
+        setup_client_action
+    },
     {
         "maximizefull",
         action_maximize_full,
@@ -591,6 +613,11 @@ ActionString actionstrings[] =
         action_toggle_maximize_vert,
         setup_client_action
     },
+    {
+        "togglefullscreen",
+        action_toggle_fullscreen,
+        setup_client_action
+    },
     {
         "sendtodesktop",
         action_send_to_desktop,
@@ -857,7 +884,21 @@ ObAction *action_parse(ObParseInst *i, xmlDocPtr doc, xmlNodePtr node,
                        act->func == action_resize_relative_horz ||
                        act->func == action_resize_relative_vert) {
                 if ((n = parse_find_node("delta", node->xmlChildrenNode)))
-                    act->data.relative.delta = parse_int(doc, n);
+                    act->data.relative.deltax = parse_int(doc, n);
+            } else if (act->func == action_move_relative) {
+                if ((n = parse_find_node("x", node->xmlChildrenNode)))
+                    act->data.relative.deltax = parse_int(doc, n);
+                if ((n = parse_find_node("y", node->xmlChildrenNode)))
+                    act->data.relative.deltay = parse_int(doc, n);
+            } else if (act->func == action_resize_relative) {
+                if ((n = parse_find_node("left", node->xmlChildrenNode)))
+                    act->data.relative.deltaxl = parse_int(doc, n);
+                if ((n = parse_find_node("up", node->xmlChildrenNode)))
+                    act->data.relative.deltayu = parse_int(doc, n);
+                if ((n = parse_find_node("right", node->xmlChildrenNode)))
+                    act->data.relative.deltax = parse_int(doc, n);
+                if ((n = parse_find_node("down", node->xmlChildrenNode)))
+                    act->data.relative.deltay = parse_int(doc, n);
             } else if (act->func == action_desktop) {
                 if ((n = parse_find_node("desktop", node->xmlChildrenNode)))
                     act->data.desktop.desk = parse_int(doc, n);
@@ -896,6 +937,13 @@ ObAction *action_parse(ObParseInst *i, xmlDocPtr doc, xmlNodePtr node,
             } else if (act->func == action_directional_focus) {
                 if ((n = parse_find_node("dialog", node->xmlChildrenNode)))
                     act->data.cycle.dialog = parse_bool(doc, n);
+            } else if (act->func == action_raise ||
+                       act->func == action_lower ||
+                       act->func == action_raiselower ||
+                       act->func == action_shadelower ||
+                       act->func == action_unshaderaise) {
+                if ((n = parse_find_node("group", node->xmlChildrenNode)))
+                    act->data.stacking.group = parse_bool(doc, n);
             }
             INTERACTIVE_LIMIT(act, uact);
         }
@@ -1025,12 +1073,20 @@ void action_focus(union ActionData *data)
 
 void action_unfocus (union ActionData *data)
 {
-    client_unfocus(data->client.any.c);
+    if (data->client.any.c == focus_client);
+        focus_fallback(OB_FOCUS_FALLBACK_UNFOCUSING);
 }
 
 void action_iconify(union ActionData *data)
 {
+    client_action_start(data);
     client_iconify(data->client.any.c, TRUE, TRUE);
+    client_action_end(data);
+}
+
+void action_focus_order_to_bottom(union ActionData *data)
+{
+    focus_order_to_bottom(data->client.any.c);
 }
 
 void action_raiselower(union ActionData *data)
@@ -1040,17 +1096,19 @@ void action_raiselower(union ActionData *data)
     gboolean raise = FALSE;
 
     for (it = stacking_list; it; it = g_list_next(it)) {
-        ObClient *cit = it->data;
+        if (WINDOW_IS_CLIENT(it->data)) {
+            ObClient *cit = it->data;
 
-        if (cit == c) break;
-        if (client_normal(cit) == client_normal(c) &&
-            cit->layer == c->layer &&
-            cit->frame->visible &&
-            !client_search_transient(c, cit))
-        {
-            if (RECT_INTERSECTS_RECT(cit->frame->area, c->frame->area)) {
-                raise = TRUE;
-                break;
+            if (cit == c) break;
+            if (client_normal(cit) == client_normal(c) &&
+                    cit->layer == c->layer &&
+                    cit->frame->visible &&
+                    !client_search_transient(c, cit))
+            {
+                if (RECT_INTERSECTS_RECT(cit->frame->area, c->frame->area)) {
+                    raise = TRUE;
+                    break;
+                }
             }
         }
     }
@@ -1064,7 +1122,7 @@ void action_raiselower(union ActionData *data)
 void action_raise(union ActionData *data)
 {
     client_action_start(data);
-    stacking_raise(CLIENT_AS_WINDOW(data->client.any.c));
+    stacking_raise(CLIENT_AS_WINDOW(data->client.any.c), data->stacking.group);
     client_action_end(data);
 }
 
@@ -1087,7 +1145,7 @@ void action_shadelower(union ActionData *data)
 void action_lower(union ActionData *data)
 {
     client_action_start(data);
-    stacking_lower(CLIENT_AS_WINDOW(data->client.any.c));
+    stacking_lower(CLIENT_AS_WINDOW(data->client.any.c), data->stacking.group);
     client_action_end(data);
 }
 
@@ -1133,7 +1191,7 @@ void action_move_relative_horz(union ActionData *data)
 {
     ObClient *c = data->relative.any.c;
     client_action_start(data);
-    client_move(c, c->area.x + data->relative.delta, c->area.y);
+    client_move(c, c->area.x + data->relative.deltax, c->area.y);
     client_action_end(data);
 }
 
@@ -1141,7 +1199,18 @@ void action_move_relative_vert(union ActionData *data)
 {
     ObClient *c = data->relative.any.c;
     client_action_start(data);
-    client_move(c, c->area.x, c->area.y + data->relative.delta);
+    client_move(c, c->area.x, c->area.y + data->relative.deltax);
+    client_action_end(data);
+}
+
+void action_move_to_center(union ActionData *data)
+{
+    ObClient *c = data->client.any.c;
+    Rect *area;
+    area = screen_area_monitor(c->desktop, 0);
+    client_action_start(data);
+    client_move(c, area->width / 2 - c->area.width / 2,
+                area->height / 2 - c->area.height / 2);
     client_action_end(data);
 }
 
@@ -1150,7 +1219,7 @@ void action_resize_relative_horz(union ActionData *data)
     ObClient *c = data->relative.any.c;
     client_action_start(data);
     client_resize(c,
-                  c->area.width + data->relative.delta * c->size_inc.width,
+                  c->area.width + data->relative.deltax * c->size_inc.width,
                   c->area.height);
     client_action_end(data);
 }
@@ -1161,11 +1230,34 @@ void action_resize_relative_vert(union ActionData *data)
     if (!c->shaded) {
         client_action_start(data);
         client_resize(c, c->area.width, c->area.height +
-                      data->relative.delta * c->size_inc.height);
+                      data->relative.deltax * c->size_inc.height);
         client_action_end(data);
     }
 }
 
+void action_move_relative(union ActionData *data)
+{
+    ObClient *c = data->relative.any.c;
+    client_action_start(data);
+    client_move(c, c->area.x + data->relative.deltax, c->area.y +
+                data->relative.deltay);
+    client_action_end(data);
+}
+
+void action_resize_relative(union ActionData *data)
+{
+    ObClient *c = data->relative.any.c;
+    client_action_start(data);
+    client_move_resize(c,
+                  c->area.x - data->relative.deltaxl * c->size_inc.width,
+                  c->area.y - data->relative.deltayu * c->size_inc.height,
+                  c->area.width + data->relative.deltax  * c->size_inc.width
+                                + data->relative.deltaxl * c->size_inc.width,
+                  c->area.height + data->relative.deltay  * c->size_inc.height
+                                 + data->relative.deltayu * c->size_inc.height);
+    client_action_end(data);
+}
+
 void action_maximize_full(union ActionData *data)
 {
     client_action_start(data);
@@ -1234,6 +1326,14 @@ void action_toggle_maximize_vert(union ActionData *data)
     client_action_end(data);
 }
 
+void action_toggle_fullscreen(union ActionData *data)
+{
+    client_action_start(data);
+    client_fullscreen(data->client.any.c,
+                      !(data->client.any.c->fullscreen), TRUE);
+    client_action_end(data);
+}
+
 void action_send_to_desktop(union ActionData *data)
 {
     ObClient *c = data->sendto.any.c;
@@ -1331,25 +1431,40 @@ void action_toggle_decorations(union ActionData *data)
 
 static guint32 pick_corner(gint x, gint y, gint cx, gint cy, gint cw, gint ch)
 {
-    if ((cw / 3 < 1) || (x - cx > cw / 3 * 2)) {
-        if ((ch / 3 < 1) || (y - cy > ch / 3 * 2))
-            return prop_atoms.net_wm_moveresize_size_bottomright;
-        else if (y - cy < ch / 3)
-            return prop_atoms.net_wm_moveresize_size_topright;
-        else
-            return prop_atoms.net_wm_moveresize_size_right;
-    } else if (x - cx < cw / 3) {
-        if (y - cy > ch / 3 * 2)
-            return prop_atoms.net_wm_moveresize_size_bottomleft;
-        else if (y - cy < ch / 3)
-            return prop_atoms.net_wm_moveresize_size_topleft;
-        else
-            return prop_atoms.net_wm_moveresize_size_left;
+    if (config_resize_four_corners) {
+        if (x - cx > cw / 2) {
+            if (y - cy > ch / 2)
+                return prop_atoms.net_wm_moveresize_size_bottomright;
+            else
+                return prop_atoms.net_wm_moveresize_size_topright;
+        } else {
+            if (y - cy > ch / 2)
+                return prop_atoms.net_wm_moveresize_size_bottomleft;
+            else
+                return prop_atoms.net_wm_moveresize_size_topleft;
+        }
     } else {
-        if (y - cy > ch / 2)
-            return prop_atoms.net_wm_moveresize_size_bottom;
-        else
-            return prop_atoms.net_wm_moveresize_size_top;
+        if (x - cx > cw * 2 / 3) {
+            if (y - cy > ch * 2 / 3)
+                return prop_atoms.net_wm_moveresize_size_bottomright;
+            else if (y - cy < ch / 3)
+                return prop_atoms.net_wm_moveresize_size_topright;
+            else
+                return prop_atoms.net_wm_moveresize_size_right;
+        } else if (x - cx < cw / 3) {
+            if (y - cy > ch * 2 / 3)
+                return prop_atoms.net_wm_moveresize_size_bottomleft;
+            else if (y - cy < ch / 3)
+                return prop_atoms.net_wm_moveresize_size_topleft;
+            else
+                return prop_atoms.net_wm_moveresize_size_left;
+        } else
+            if (y - cy > ch * 2 / 3)
+                return prop_atoms.net_wm_moveresize_size_bottom;
+            else if (y - cy < ch / 3)
+                return prop_atoms.net_wm_moveresize_size_top;
+            else
+                return prop_atoms.net_wm_moveresize_move;
     }
 }
 
@@ -1411,7 +1526,7 @@ void action_cycle_windows(union ActionData *data)
        on us */
     event_halt_focus_delay();
 
-    focus_cycle(data->cycle.forward, data->cycle.linear,
+    focus_cycle(data->cycle.forward, data->cycle.linear, data->any.interactive,
                 data->cycle.dialog,
                 data->cycle.inter.final, data->cycle.inter.cancel);
 }
@@ -1423,6 +1538,7 @@ void action_directional_focus(union ActionData *data)
     event_halt_focus_delay();
 
     focus_directional_cycle(data->interdiraction.direction,
+                            data->any.interactive,
                             data->interdiraction.dialog,
                             data->interdiraction.inter.final,
                             data->interdiraction.inter.cancel);
@@ -1466,6 +1582,10 @@ void action_growtoedge(union ActionData *data)
     ObClient *c = data->diraction.any.c;
     Rect *a;
 
+    //FIXME growtoedge resizes shaded windows to 0 height
+    if (c->shaded)
+        return;
+
     a = screen_area(c->desktop);
     x = c->frame->area.x;
     y = c->frame->area.y;
