@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    action.h for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -82,7 +83,10 @@ struct Activate {
 
 struct MoveResizeRelative {
     struct AnyAction any;
-    gint delta;
+    gint deltax;
+    gint deltay;
+    gint deltaxl;
+    gint deltayu;
 };
 
 struct SendToDesktop {
@@ -134,6 +138,11 @@ struct CycleWindows {
     gboolean dialog;
 };
 
+struct Stacking {
+    struct AnyAction any;
+    gboolean group;
+};
+
 union ActionData {
     struct AnyAction any;
     struct InteractiveAction inter;
@@ -151,6 +160,7 @@ union ActionData {
     struct ShowMenu showmenu;
     struct CycleWindows cycle;
     struct Layer layer;
+    struct Stacking stacking;
 };
 
 struct _ObAction {
@@ -174,6 +184,8 @@ struct _ObAction {
    action_move_relative_vert - the delta
    action_resize_relative_horz - the delta
    action_resize_relative_vert - the delta
+   action_move_relative - the deltas
+   action_resize_relative - the deltas
 */
 
 ObAction* action_from_string(const gchar *name, ObUserAction uact);
@@ -224,6 +236,8 @@ void action_unfocus(union ActionData *data);
 /* ClientAction */
 void action_iconify(union ActionData *data);
 /* ClientAction */
+void action_focus_order_to_bottom(union ActionData *data);
+/* ClientAction */
 void action_raiselower(union ActionData *data);
 /* ClientAction */
 void action_raise(union ActionData *data);
@@ -250,6 +264,12 @@ void action_move_relative_horz(union ActionData *data);
 /* MoveResizeRelative */
 void action_move_relative_vert(union ActionData *data);
 /* MoveResizeRelative */
+void action_move_relative(union ActionData *data);
+/* MoveResizeRelative */
+void action_resize_relative(union ActionData *data);
+/* ClientAction */
+void action_move_to_center(union ActionData *data);
+/* MoveResizeRelative */
 void action_resize_relative_horz(union ActionData *data);
 /* MoveResizeRelative */
 void action_resize_relative_vert(union ActionData *data);
@@ -271,6 +291,8 @@ void action_maximize_vert(union ActionData *data);
 void action_unmaximize_vert(union ActionData *data);
 /* ClientAction */
 void action_toggle_maximize_vert(union ActionData *data);
+/* ClientAction */
+void action_toggle_fullscreen(union ActionData *data);
 /* SendToDesktop */
 void action_send_to_desktop(union ActionData *data);
 /* SendToDesktopDirection */
