@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    client.h for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -32,8 +33,9 @@ struct _ObFrame;
 struct _ObGroup;
 struct _ObSessionState;
 
-typedef struct _ObClient     ObClient;
-typedef struct _ObClientIcon ObClientIcon;
+typedef struct _ObClient      ObClient;
+typedef struct _ObClientIcon  ObClientIcon;
+typedef struct _ObAppSettings ObAppSettings;
 
 /* The value in client.transient_for indicating it is a transient for its
    group instead of for a single window */
@@ -201,9 +203,11 @@ struct _ObClient
     /*! True if the client supports the delete_window protocol */
     gboolean delete_window;
   
-    /*! Was the window's position requested by the application? if not, we
+    /*! Was the window's position requested by the application or the user?
+      if by the application, we force it completely onscreen, if by the user
+      we only force it if it tries to go completely offscreen, if neither, we
       should place the window ourselves when it first appears */
-    gboolean positioned;
+    guint positioned;
   
     /*! Can the window receive input focus? */
     gboolean can_focus;
@@ -267,6 +271,32 @@ struct _ObClient
     guint nicons;
 };
 
+struct _ObAppSettings
+{
+    gchar *class;
+    gchar *name;
+    gchar *role;
+
+    Point position;
+    gboolean center_x;
+    gboolean center_y;
+    gboolean pos_given;
+
+    guint desktop;
+    gint shade;
+    gint decor;
+    gint focus;
+    gint head;
+    gint iconic;
+    gint skip_pager;
+    gint skip_taskbar;
+    gint max_horz;
+    gint max_vert;
+    gint fullscreen;
+
+    gint layer;
+};
+
 extern GList *client_list;
 
 void client_startup(gboolean reconfig);
