@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    client_list_menu.c for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -23,6 +24,7 @@
 #include "screen.h"
 #include "client.h"
 #include "focus.h"
+#include "config.h"
 #include "gettext.h"
 
 #include <glib.h>
@@ -73,7 +75,7 @@ static void desk_menu_update(ObMenuFrame *frame, gpointer data)
             e = menu_add_normal(menu, i,
                                 (c->iconic ? c->icon_title : c->title), acts);
 
-            if ((icon = client_icon(c, 32, 32))) {
+            if (config_menu_client_list_icons && (icon = client_icon(c, 32, 32))) {
                 e->data.normal.icon_width = icon->width;
                 e->data.normal.icon_height = icon->height;
                 e->data.normal.icon_data = icon->data;
@@ -153,10 +155,40 @@ static void self_update(ObMenuFrame *frame, gpointer data)
     }
 }
 
-void client_list_menu_startup()
+static void client_dest(ObClient *client, gpointer data)
+{
+    /* This concise function removes all references to a closed
+     * client in the client_list_menu, so we don't have to check
+     * in client.c */
+    GSList *it;
+    for (it = desktop_menus; it; it = g_slist_next(it)) {
+        ObMenu *mit = it->data;
+        GList *eit;
+        for (eit = mit->entries; eit; eit = g_list_next(eit)) {
+            ObMenuEntry *meit = eit->data;
+            if (meit->type == OB_MENU_ENTRY_TYPE_NORMAL) {
+                ObAction *a = meit->data.normal.actions->data;
+                ObClient *c = a->data.any.c;
+                if (c == client)
+                    a->data.any.c = NULL;
+            }
+        }
+    }
+}
+
+void client_list_menu_startup(gboolean reconfig)
 {
     ObMenu *menu;
 
+    if (!reconfig)
+        client_add_destructor(client_dest, NULL);
+
     menu = menu_new(MENU_NAME, _("Desktops"), NULL);
     menu_set_update_func(menu, self_update);
 }
+
+void client_list_menu_shutdown(gboolean reconfig)
+{
+    if (!reconfig)
+        client_remove_destructor(client_dest);
+}
