@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    client_list_menu.h for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -19,6 +20,7 @@
 #ifndef ob__client_list_menu_h
 #define ob__client_list_menu_h
 
-void client_list_menu_startup();
+void client_list_menu_startup(gboolean reconfig);
+void client_list_menu_shutdown(gboolean reconfig);
 
 #endif
