@@ -1,7 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    event.c for the Openbox window manager
-   Copyright (c) 2004        Mikael Magnusson
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -51,6 +51,9 @@
 #ifdef HAVE_SIGNAL_H
 #  include <signal.h>
 #endif
+#ifdef XKB
+#  include <X11/XKBlib.h>
+#endif
 
 #ifdef USE_SM
 #include <X11/ICE/ICElib.h>
@@ -172,6 +175,7 @@ void event_shutdown(gboolean reconfig)
 #endif
 
     client_remove_destructor(focus_delay_client_dest);
+    client_remove_destructor(event_client_dest);
     XFreeModifiermap(modmap);
 }
 
@@ -259,6 +263,9 @@ static void event_set_lasttime(XEvent *e)
 
 static void event_hack_mods(XEvent *e)
 {
+#ifdef XKB
+    XkbStateRec xkb_state;
+#endif
     KeyCode *kp;
     gint i, k;
 
@@ -274,6 +281,12 @@ static void event_hack_mods(XEvent *e)
         STRIP_MODS(e->xkey.state);
         /* remove from the state the mask of the modifier being released, if
            it is a modifier key being released (this is a little ugly..) */
+#ifdef XKB
+        if (XkbGetState(ob_display, XkbUseCoreKbd, &xkb_state) == Success) {
+            e->xkey.state = xkb_state.compat_state;
+            break;
+        }
+#endif
         kp = modmap->modifiermap;
         for (i = 0; i < mask_table_size; ++i) {
             for (k = 0; k < modmap->max_keypermod; ++k) {
@@ -588,11 +601,6 @@ static void event_handle_root(XEvent *e)
         break;
     default:
         ;
-#ifdef VIDMODE
-        if (extensions_vidmode && e->type == extensions_vidmode_event_basep) {
-            ob_debug("VIDMODE EVENT\n");
-        }
-#endif
     }
 }
 
@@ -716,7 +724,7 @@ static void event_handle_client(ObClient *client, XEvent *e)
             if (config_focus_follow && config_focus_delay)
                 ob_main_loop_timeout_remove_data(ob_main_loop,
                                                  focus_delay_func,
-                                                 client);
+                                                 client, TRUE);
             break;
         default:
             break;
@@ -1134,7 +1142,10 @@ static void event_handle_dock(ObDock *s, XEvent *e)
 {
     switch (e->type) {
     case ButtonPress:
-        stacking_raise(DOCK_AS_WINDOW(s));
+        if (e->xbutton.button == 1)
+            stacking_raise(DOCK_AS_WINDOW(s), FALSE);
+        else if (e->xbutton.button == 2)
+            stacking_lower(DOCK_AS_WINDOW(s), FALSE);
         break;
     case EnterNotify:
         dock_hide(FALSE);
@@ -1276,7 +1287,7 @@ static gboolean focus_delay_func(gpointer data)
 
 static void focus_delay_client_dest(ObClient *client, gpointer data)
 {
-    ob_main_loop_timeout_remove_data(ob_main_loop, focus_delay_func, client);
+    ob_main_loop_timeout_remove_data(ob_main_loop, focus_delay_func, client, TRUE);
 }
 
 static void event_client_dest(ObClient *client, gpointer data)
