@@ -1,19 +1,20 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
-extensions.c for the Openbox window manager
-Copyright (c) 2003        Ben Jansens
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-See the COPYING file for a copy of the GNU General Public License.
+   extensions.c for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
+   Copyright (c) 2003        Ben Jansens
+   
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+   
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+   
+   See the COPYING file for a copy of the GNU General Public License.
 */
 
 #include "openbox.h"
@@ -29,8 +30,6 @@ gboolean extensions_xinerama  = FALSE;
 gint     extensions_xinerama_event_basep;
 gboolean extensions_randr     = FALSE;
 gint     extensions_randr_event_basep;
-gboolean extensions_vidmode   = FALSE;
-gint     extensions_vidmode_event_basep;
 
 void extensions_query_all()
 {
@@ -60,12 +59,6 @@ void extensions_query_all()
         XRRQueryExtension(ob_display, &extensions_randr_event_basep,
                           &junk);
 #endif
-
-#ifdef VIDMODE
-    extensions_vidmode =
-        XF86VidModeQueryExtension(ob_display, &extensions_vidmode_event_basep,
-                                  &junk);
-#endif
 }
 
 void extensions_xinerama_screens(Rect **xin_areas, guint *nxin)
