@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    focus.h for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -48,6 +49,7 @@ void focus_set_client(struct _ObClient *client);
 typedef enum {
     OB_FOCUS_FALLBACK_UNFOCUSING, /*!< forcefully remove focus from the
                                     current window */
+    OB_FOCUS_FALLBACK_CLOSED,     /*!< closed the window with focus */
     OB_FOCUS_FALLBACK_NOFOCUS     /*!< nothing has focus for some reason */
 } ObFocusFallbackType;
 
@@ -57,9 +59,9 @@ struct _ObClient* focus_fallback_target(ObFocusFallbackType type);
 void focus_fallback(ObFocusFallbackType type);
 
 /*! Cycle focus amongst windows. */
-void focus_cycle(gboolean forward, gboolean linear,
+void focus_cycle(gboolean forward, gboolean linear, gboolean interactive,
                  gboolean dialog, gboolean done, gboolean cancel);
-void focus_directional_cycle(ObDirection dir,
+void focus_directional_cycle(ObDirection dir, gboolean interactive,
                              gboolean dialog, gboolean done, gboolean cancel);
 void focus_cycle_draw_indicator();
 
