@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    grab.c for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -75,7 +76,7 @@ gboolean grab_pointer(gboolean grab, ObCursor cur)
         if (pgrabs++ == 0) {
             ret = XGrabPointer(ob_display, screen_support_win,
                                False, GRAB_PTR_MASK, GrabModeAsync,
-                               GrabModeAsync, FALSE,
+                               GrabModeAsync, None,
                                ob_cursor(cur), event_lasttime) == Success;
             if (!ret)
                 --pgrabs;
@@ -97,7 +98,7 @@ gboolean grab_pointer_window(gboolean grab, ObCursor cur, Window win)
     if (grab) {
         if (pgrabs++ == 0) {
             ret = XGrabPointer(ob_display, win, False, GRAB_PTR_MASK,
-                               GrabModeAsync, GrabModeAsync, TRUE,
+                               GrabModeAsync, GrabModeAsync, None,
                                ob_cursor(cur),
                                event_lasttime) == Success;
             if (!ret)
