@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    keyboard.c for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -119,7 +120,7 @@ gboolean keyboard_bind(GList *keylist, ObAction *action)
         return FALSE;
 
     if ((t = tree_find(tree, &conflict)) != NULL) {
-	/* already bound to something, use the existing tree */
+        /* already bound to something, use the existing tree */
         tree_destroy(tree);
         tree = NULL;
     } else
@@ -229,9 +230,9 @@ gboolean keyboard_process_interactive_grab(const XEvent *e, ObClient **client)
              !(s->state & e->xkey.state)))
             done = TRUE;
         else if (e->type == KeyPress) {
-            if (e->xkey.keycode == ob_keycode(OB_KEY_RETURN))
+            /*if (e->xkey.keycode == ob_keycode(OB_KEY_RETURN))
                 done = TRUE;
-            else if (e->xkey.keycode == ob_keycode(OB_KEY_ESCAPE))
+            else */if (e->xkey.keycode == ob_keycode(OB_KEY_ESCAPE))
                 cancel = done = TRUE;
         }
         if (done) {
@@ -287,6 +288,11 @@ void keyboard_event(ObClient *client, const XEvent *e)
     }
 }
 
+gboolean keyboard_interactively_grabbed()
+{
+    return !!interactive_states;
+}
+
 void keyboard_startup(gboolean reconfig)
 {
     grab_keys(TRUE);
