@@ -1,7 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    mainloop.c for the Openbox window manager
-   Copyright (c) 2004        Mikael Magnusson
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -608,16 +608,18 @@ void ob_main_loop_timeout_remove(ObMainLoop *loop,
     }
 }
 
-void ob_main_loop_timeout_remove_data(ObMainLoop *loop,
-                                      GSourceFunc handler,
-                                      gpointer data)
+void ob_main_loop_timeout_remove_data(ObMainLoop *loop, GSourceFunc handler,
+                                      gpointer data, gboolean cancel_dest)
 {
     GSList *it;
 
     for (it = loop->timers; it; it = g_slist_next(it)) {
         ObMainLoopTimer *t = it->data;
-        if (t->func == handler && t->data == data)
+        if (t->func == handler && t->data == data) {
             t->del_me = TRUE;
+            if (cancel_dest)
+                t->destroy = NULL;
+        }
     }
 }
 
