@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    mainloop.h for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -65,7 +66,8 @@ void ob_main_loop_timeout_remove(ObMainLoop *loop,
                                  GSourceFunc handler);
 void ob_main_loop_timeout_remove_data(ObMainLoop *loop,
                                       GSourceFunc handler,
-                                      gpointer data);
+                                      gpointer data,
+                                      gboolean cancel_dest);
 
 struct _ObAction;
 
