@@ -1,7 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    moveresize.c for the Openbox window manager
-   Copyright (c) 2004        Mikael Magnusson
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -193,9 +193,10 @@ void moveresize_end(gboolean cancel)
 
 static void do_move(gboolean resist)
 {
-    if (resist)
+    if (resist) {
         resist_move_windows(moveresize_client, &cur_x, &cur_y);
-    resist_move_monitors(moveresize_client, &cur_x, &cur_y);
+        resist_move_monitors(moveresize_client, &cur_x, &cur_y);
+    }
 
     /* get where the client should be */
     frame_frame_gravity(moveresize_client->frame, &cur_x, &cur_y);
@@ -216,9 +217,10 @@ static void do_resize(gboolean resist)
     cur_y += moveresize_client->frame->size.top +
         moveresize_client->frame->size.bottom;
 
-    if (resist)
+    if (resist) {
         resist_size_windows(moveresize_client, &cur_x, &cur_y, lockcorner);
-    resist_size_monitors(moveresize_client, &cur_x, &cur_y, lockcorner);
+        resist_size_monitors(moveresize_client, &cur_x, &cur_y, lockcorner);
+    }
 
     cur_x -= moveresize_client->frame->size.left +
         moveresize_client->frame->size.right;
