@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    place.h for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -22,6 +23,7 @@
 #include <glib.h>
 
 struct _ObClient;
+struct _ObAppSettings;
 
 typedef enum
 {
@@ -29,6 +31,7 @@ typedef enum
     OB_PLACE_POLICY_MOUSE
 } ObPlacePolicy;
 
-void place_client(struct _ObClient *client, gint *x, gint *y);
+gboolean place_client(struct _ObClient *client, gint *x, gint *y,
+                      struct _ObAppSettings *settings);
 
 #endif
