@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    prop.h for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -177,8 +178,8 @@ gboolean prop_get_string_utf8(Window win, Atom prop, gchar **ret);
 gboolean prop_get_strings_locale(Window win, Atom prop, gchar ***ret);
 gboolean prop_get_strings_utf8(Window win, Atom prop, gchar ***ret);
 
-void prop_set32(Window win, Atom prop, Atom type, guint32 val);
-void prop_set_array32(Window win, Atom prop, Atom type, guint32 *val,
+void prop_set32(Window win, Atom prop, Atom type, gulong val);
+void prop_set_array32(Window win, Atom prop, Atom type, gulong *val,
                       guint num);
 void prop_set_string_utf8(Window win, Atom prop, gchar *val);
 void prop_set_strings_utf8(Window win, Atom prop, gchar **strs);
