@@ -21,6 +21,10 @@
 #define __font_h
 #include "render.h"
 #include "geom.h"
+#ifdef USE_PANGO
+#include <pango/pango.h>
+#include <pango/pangoxft.h>
+#endif /* USE_PANGO */
 
 struct _RrFont {
     const RrInstance *inst;
@@ -29,6 +33,11 @@ struct _RrFont {
     gint shadow;
     gchar tint;
     gint offset;
+#ifdef USE_PANGO
+    PangoFontDescription *pango_font_description;
+    gint pango_ascent;
+    gint pango_descent;
+#endif /* USE_PANGO */
 };
 
 RrFont *RrFontOpen(const RrInstance *inst, gchar *fontstring);
