@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    instance.c for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
 
    This program is free software; you can redistribute it and/or modify
@@ -115,7 +116,7 @@ void RrTrueColorSetup (RrInstance *inst)
   XFree(timage);
 }
 
-#define RrPseudoNcolors(isnt) (1 << (inst->pseudo_bpc * 3))
+#define RrPseudoNcolors(inst) (1 << (inst->pseudo_bpc * 3))
 
 void RrPseudoColorSetup (RrInstance *inst)
 {
