@@ -1,6 +1,7 @@
 /* -*- indent-tabs-mode: nil; tab-width: 4; c-basic-offset: 4; -*-
 
    render.c for the Openbox window manager
+   Copyright (c) 2006        Mikael Magnusson
    Copyright (c) 2003        Ben Jansens
    Copyright (c) 2003        Derek Foreman
 
@@ -39,7 +40,7 @@ static void pixel_data_to_pixmap(RrAppearance *l,
 
 void RrPaint(RrAppearance *a, Window win, gint w, gint h)
 {
-    gint i, transferred = 0, sw;
+    gint i, transferred = 0, sw, sh, partial_w, partial_h;
     RrPixel32 *source, *dest;
     Pixmap oldp;
     RrRect tarea; /* area in which to draw textures */
@@ -47,6 +48,10 @@ void RrPaint(RrAppearance *a, Window win, gint w, gint h)
 
     if (w <= 0 || h <= 0) return;
 
+    if (a->surface.parentx < 0 || a->surface.parenty < 0) {
+        /* ob_debug("Invalid parent co-ordinates\n"); */
+        return;
+    }
     resized = (a->w != w || a->h != h);
 
     oldp = a->pixmap; /* save to free after changing the visible pixmap */
@@ -72,11 +77,26 @@ void RrPaint(RrAppearance *a, Window win, gint w, gint h)
         g_assert (a->surface.parent->w);
 
         sw = a->surface.parent->w;
+        sh = a->surface.parent->h;
+
+        if (a->surface.parentx >= sw || a->surface.parenty >= sh) {
+            return;
+        }
+
         source = (a->surface.parent->surface.pixel_data +
                   a->surface.parentx + sw * a->surface.parenty);
         dest = a->surface.pixel_data;
-        for (i = 0; i < h; i++, source += sw, dest += w) {
-            memcpy(dest, source, w * sizeof(RrPixel32));
+
+        if (a->surface.parentx + w > sw) {
+            partial_w = sw - a->surface.parentx;
+        } else partial_w = w;
+
+        if (a->surface.parenty + h > sh) {
+            partial_h = sh - a->surface.parenty;
+        } else partial_h = h;
+
+        for (i = 0; i < partial_h; i++, source += sw, dest += w) {
+            memcpy(dest, source, partial_w * sizeof(RrPixel32));
         }
     } else
         RrRender(a, w, h);
@@ -94,7 +114,7 @@ void RrPaint(RrAppearance *a, Window win, gint w, gint h)
         case RR_TEXTURE_TEXT:
             if (!transferred) {
                 transferred = 1;
-                if (a->surface.grad != RR_SURFACE_SOLID)
+                if ((a->surface.grad != RR_SURFACE_SOLID) || (a->surface.interlaced))
                     pixel_data_to_pixmap(a, 0, 0, w, h);
             }
             if (a->xftdraw == NULL) {
@@ -107,7 +127,7 @@ void RrPaint(RrAppearance *a, Window win, gint w, gint h)
         case RR_TEXTURE_LINE_ART:
             if (!transferred) {
                 transferred = 1;
-                if (a->surface.grad != RR_SURFACE_SOLID)
+                if ((a->surface.grad != RR_SURFACE_SOLID) || (a->surface.interlaced))
                     pixel_data_to_pixmap(a, 0, 0, w, h);
             }
             XDrawLine(RrDisplay(a->inst), a->pixmap,
@@ -120,7 +140,7 @@ void RrPaint(RrAppearance *a, Window win, gint w, gint h)
         case RR_TEXTURE_MASK:
             if (!transferred) {
                 transferred = 1;
-                if (a->surface.grad != RR_SURFACE_SOLID)
+                if ((a->surface.grad != RR_SURFACE_SOLID) || (a->surface.interlaced))
                     pixel_data_to_pixmap(a, 0, 0, w, h);
             }
             RrPixmapMaskDraw(a->pixmap, &a->texture[i].data.mask, &tarea);
@@ -137,7 +157,7 @@ void RrPaint(RrAppearance *a, Window win, gint w, gint h)
 
     if (!transferred) {
         transferred = 1;
-        if (a->surface.grad != RR_SURFACE_SOLID)
+        if ((a->surface.grad != RR_SURFACE_SOLID) || (a->surface.interlaced))
             pixel_data_to_pixmap(a, 0, 0, w, h);
     }
 
@@ -255,7 +275,7 @@ void RrAppearanceFree(RrAppearance *a)
         RrColorFree(p->bevel_dark);
         RrColorFree(p->bevel_light);
         g_free(p->pixel_data);
-
+        p->pixel_data = NULL;
         g_free(a);
     }
 }
@@ -311,7 +331,7 @@ void RrMargins (RrAppearance *a, gint *l, gint *t, gint *r, gint *b)
 void RrMinsize(RrAppearance *a, gint *w, gint *h)
 {
     gint i;
-    gint m;
+    RrSize *m;
     gint l, t, r, b;
     *w = *h = 0;
 
@@ -326,9 +346,10 @@ void RrMinsize(RrAppearance *a, gint *w, gint *h)
         case RR_TEXTURE_TEXT:
             m = RrFontMeasureString(a->texture[i].data.text.font,
                                     a->texture[i].data.text.string);
-            *w = MAX(*w, m);
-            m = RrFontHeight(a->texture[i].data.text.font);
-            *h += MAX(*h, m);
+            *w = MAX(*w, m->width + 4);
+            m->height = RrFontHeight(a->texture[i].data.text.font);
+            *h += MAX(*h, m->height);
+            g_free(m);
             break;
         case RR_TEXTURE_RGBA:
             *w += MAX(*w, a->texture[i].data.rgba.width);
@@ -352,6 +373,14 @@ void RrMinsize(RrAppearance *a, gint *w, gint *h)
     if (*h < 1) *h = 1;
 }
 
+static void reverse_bits(gchar *c, gint n)
+{
+    gint i;
+    for (i = 0; i < n; i++, c++)
+        *c = (((*c * 0x0802UL & 0x22110UL) |
+               (*c * 0x8020UL & 0x88440UL)) * 0x10101UL) >> 16;
+}
+
 gboolean RrPixmapToRGBA(const RrInstance *inst,
                         Pixmap pmap, Pixmap mask,
                         gint *w, gint *h, RrPixel32 **data)
@@ -361,9 +390,10 @@ gboolean RrPixmapToRGBA(const RrInstance *inst,
     guint pw, ph, mw, mh, xb, xd, i, x, y, di;
     XImage *xi, *xm = NULL;
 
-    if (!XGetGeometry(RrDisplay(inst),
-                      pmap, &xr, &xx, &xy, &pw, &ph, &xb, &xd))
+    if (!XGetGeometry(RrDisplay(inst), pmap,
+                      &xr, &xx, &xy, &pw, &ph, &xb, &xd))
         return FALSE;
+
     if (mask) {
         if (!XGetGeometry(RrDisplay(inst), mask,
                           &xr, &xx, &xy, &mw, &mh, &xb, &xd))
@@ -384,8 +414,13 @@ gboolean RrPixmapToRGBA(const RrInstance *inst,
             XDestroyImage(xi);
             return FALSE;
         }
+        if ((xm->bits_per_pixel == 1) && (xm->bitmap_bit_order != LSBFirst))
+            reverse_bits(xm->data, xm->bytes_per_line * xm->height);
     }
 
+    if ((xi->bits_per_pixel == 1) && (xi->bitmap_bit_order != LSBFirst))
+        reverse_bits(xi->data, xi->bytes_per_line * xi->height);
+
     *data = g_new(RrPixel32, pw * ph);
     RrIncreaseDepth(inst, *data, xi);
 
